@@ -247,6 +247,7 @@ class cache(ApiviewDecorator):
     def __init__(self, key, expire=None, cache_name="default", get_from_cache=None, set_to_cache=True, disable_get_from_cache_header=None, batch_mode=False, ignore_cache_errors=True, related_models=None):
         self.key = key
         self.expire = expire or getattr(settings, "DJANGO_APIVIEW_DEFAULT_CACHE_EXPIRE", None)
+        self.expire = self.expire or int(self.expire) or None
         self.cache_name = cache_name
         self.get_from_cache = get_from_cache
         self.set_to_cache = set_to_cache
@@ -285,7 +286,7 @@ class cache(ApiviewDecorator):
             try:
                 cache = get_redis_connection(cache_name)
             except Exception as error:
-                logger.error("get redis connection failed @cache, error_message={0}".format(str(error)))
+                logger.exception("get redis connection failed @cache, error_message={0}".format(str(error)))
                 if ignore_cache_errors:
                     cache = None
                 else:
@@ -302,7 +303,7 @@ class cache(ApiviewDecorator):
                 if not result_text is None:
                     return json.loads(result_text)
             except Exception as error:
-                logger.error("query redis failed @cache, error_message={0}".format(str(error)))
+                logger.exception("query redis failed @cache, error_message={0}".format(str(error)))
                 if not ignore_cache_errors:
                     raise
 
@@ -322,12 +323,11 @@ class cache(ApiviewDecorator):
                     **_django_apiview_request.data, **kwargs,
                     )
             result_text = json.dumps(result, cls=SimpleJsonEncoder, allow_nan=True, sort_keys=True)
+            cache.set(key, result_text)
             if expire:
-                cache.set(key, result_text,  keepttl=expire)
-            else:
-                cache.set(key, result_text)
-
-        if cache and set_to_cache:
+                cache.expire(key, expire) # Old version redis don't support add ttl while doing set key value, so do set ttl separately
+        
+        if cache and set_to_cache_final:
             try:
                 if batch_mode:
                     if isinstance(result, list):
@@ -339,7 +339,7 @@ class cache(ApiviewDecorator):
                 else:
                     _set_cache(result)
             except Exception as error:
-                logger.error("write redis failed @cache, error_message={0}".format(str(error)))
+                logger.exception("write redis failed @cache, error_message={0}".format(str(error)))
                 if not ignore_cache_errors:
                     raise
 
